@@ -9,12 +9,12 @@ from babel import Locale  # type: ignore
 from fastapi import Depends, Response, status
 from fastapi.responses import FileResponse, RedirectResponse
 from fastapi.staticfiles import StaticFiles
+from fps_frontend.config import get_frontend_config  # type: ignore
 from starlette.requests import Request  # type: ignore
 
 import jupyverse  # type: ignore
 from jupyverse import User, current_user, update_user
 
-from .config import get_lab_config  # type: ignore
 from .utils import get_federated_extensions
 
 try:
@@ -57,12 +57,12 @@ def init_router(router, redirect_after_root):
     @router.get("/", name="root")
     async def get_root(
         response: Response,
-        lab_config=Depends(get_lab_config),
+        frontend_config=Depends(get_frontend_config),
         user: User = Depends(current_user()),
     ):
         # auto redirect
         response.status_code = status.HTTP_302_FOUND
-        response.headers["Location"] = lab_config.base_url + redirect_after_root
+        response.headers["Location"] = frontend_config.base_url + redirect_after_root
 
     @router.get("/favicon.ico")
     async def get_favicon():
@@ -85,10 +85,10 @@ def init_router(router, redirect_after_root):
 
     @router.get("/lab/api/translations/")
     async def get_translations_(
-        lab_config=Depends(get_lab_config),
+        frontend_config=Depends(get_frontend_config),
         user: User = Depends(current_user()),
     ):
-        return RedirectResponse(f"{lab_config.base_url}lab/api/translations")
+        return RedirectResponse(f"{frontend_config.base_url}lab/api/translations")
 
     @router.get("/lab/api/translations")
     async def get_translations(user: User = Depends(current_user())):
